@@ -64,6 +64,7 @@ SUPPORTED_AUDIO_FORMAT = {
         "channels": 1
     }
 }
+ERROR_IN_SEND_THREAD = 11000
 
 
 class SpeechConfig():
@@ -404,6 +405,7 @@ class Recognizer(WebSocketClient):
 
     def send_thread(self):
         """Send data to websocket"""
+        error_flag = False
         while self.is_running:
             try:
                 if self.__input_stream is not None:
@@ -411,8 +413,25 @@ class Recognizer(WebSocketClient):
                     if buf is not None and len(buf) > 0:
                         self.send(buf, binary=True)
             except KeyboardInterrupt:
+                error_flag = True
                 self.stop_continuous_recognition_async()
-        self.send("EOS")
+            except Exception as e:
+                svc_logger.error(f"Exception in send_thread: {e}")
+                error_flag = True
+                self.stop_continuous_recognition_async()
+        try:
+            # inform server that client has finished sending all audio data
+            self.send("EOS")
+        except Exception:
+            # if can't send 'EOS' to server, actively close websocket connection with server
+            error_flag = True
+            self.close()
+        finally:
+            if error_flag:
+                if self.__canceled_event.is_set:
+                    evt = {"session_id": self.session_id, "status": ERROR_IN_SEND_THREAD, "messge": "Error while sending data to server"}
+                    evt_res = EventResults(evt)
+                    self.__canceled_event.callback(evt_res)
 
     def received_message(self, message) -> None:
         """Receive result from websocket"""
